/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api;

/**
 * DefaultAnnotationVisitor.
 * @author Gael Lalire
 */
public class DefaultAnnotationVisitor implements IAnnotationVisitor {

    /**
     * An empty visitor.
     */
    public static final DefaultAnnotationVisitor EMPTY_VISITOR = new DefaultAnnotationVisitor();

    /**
     * Empty visit method.
     * @param name annotation name
     * @param value annotation value
     */
    public void visit(final String name, final Object value) {
    }

    /**
     * Empty visit annotation method.
     * @param name annotation name
     * @param desc annotation desc
     * @return itself
     */
    public IAnnotationVisitor visitAnnotation(final String name, final String desc) {
        return this;
    }

    /**
     * Empty visit array method.
     * @param name array name
     * @return itself
     */
    public IAnnotationVisitor visitArray(final String name) {
        return this;
    }

    /**
     * Empty visitEnd method.
     */
    public void visitEnd() {
    }

    /**
     * Empty visit enumeration method.
     * @param name enumeration name
     * @param desc enumeration desc
     * @param value enumeration value
     */
    public void visitEnum(final String name, final String desc, final String value) {
    }


}
