/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.configurator;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.metadata.structures.JAnnotation;

/**
 * Implements a generic getAnnotationVisitor method with map.
 * @author Gael Lalire
 */
public abstract class BasicConfigurator implements ICommonConfigurator {

    /**
     * map a annotation class name with a visitor.
     */
    private Map<String, IAnnotationVisitor> annotationVisitors;

    /**
     * Constructor.
     */
    public BasicConfigurator() {
        annotationVisitors = new HashMap<String, IAnnotationVisitor>();
    }

    /**
     * @return map where add visitor
     */
    protected Map<String, IAnnotationVisitor> getAnnotationVisitors() {
        return annotationVisitors;
    }

    /**
     * @param annotation signature of annotation
     * @return the visitor in the map or empty visitor
     */
    public IAnnotationVisitor getAnnotationVisitor(final JAnnotation annotation) {
        return annotationVisitors.get(annotation.getClassName());
    }

    /**
     * This one do nothing, you may override it.
     * @param referencedClasses you may fill this set with class referenced in current metadata
     */
    public void configurationComplete(final Set<String> referencedClasses) {
    }

}
