/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.configurator.metadata.specific;

import org.ow2.util.scan.api.configurator.ICommonConfigurator;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.ow2.util.scan.api.metadata.IMethodMetadata;

/**
 * ISpecificClassConfigurator.
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 * @author Gael Lalire
 */
public interface ISpecificClassConfigurator<
    C extends IClassMetadata<C, M, F>,
    M extends IMethodMetadata<C, M, F>,
    F extends IFieldMetadata<C, M, F>> extends ICommonConfigurator {

    /**
     * @param methodMetadata standard method metadata
     * @return specific method configurator
     */
    ISpecificMethodConfigurator createSpecificMethodConfigurator(M methodMetadata);

    /**
     * @param fieldMetadata standard field metadata
     * @return specific field configurator
     */
    ISpecificFieldConfigurator createSpecificFieldConfigurator(F fieldMetadata);

}
