/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.metadata;

import org.ow2.util.scan.api.metadata.structures.JField;

/**
 * This class represents the annotation metadata of a field.
 * @author Florent Benoit
 * @param <C> type of class metadata
 * @param <M> type of method metadata
 * @param <F> type of field metadata
 */
public abstract class FieldMetadata<
    C extends IClassMetadata<C, M, F>,
    M extends IMethodMetadata<C, M, F>,
    F extends IFieldMetadata<C, M, F>>
        extends CommonMetadata implements IFieldMetadata<C, M, F> {

    /**
     * Logger.
     */
    //private static Log logger = LogFactory.getLog(FieldAnnotationMetadata.class);

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 6915512495541617868L;

    /**
     * Method on which we got metadata.
     */
    private JField jField = null;

    /**
     * Parent metadata.
     */
    private C classAnnotationMetadata = null;

    /**
     * This field is a field from a super class ?<br>
     */
    private boolean inherited = false;


    /**
     * Constructor.
     * @param jField the field on which we will set/add metadata
     * @param classAnnotationMetadata the parent metadata.
     */
    public FieldMetadata(final JField jField, final C classAnnotationMetadata) {
        this.jField = jField;
        this.classAnnotationMetadata = classAnnotationMetadata;
    }

    /**
     * @return JMethod object
     */
    public final JField getJField() {
        return this.jField;
    }

    /**
     * @return true if this method is inherited from a super class
     */
    public final boolean isInherited() {
        return inherited;
    }

    /**
     * Sets the inheritance of this method.
     * @param inherited true if method is from a super class
     */
    public final void setInherited(final boolean inherited) {
        this.inherited = inherited;
    }

    /**
     * @return parent metadata (class)
     */
    public final C getClassMetadata() {
        return classAnnotationMetadata;
    }

}
