/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.metadata;

import java.io.Serializable;

import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * Interface of a method metadata.
 * @param <C> interface of a class metadata
 * @param <M> interface of a method metadata
 * @param <F> interface of a field metadata
 * @author Gael Lalire
 */
public interface IMethodMetadata<
    C extends IClassMetadata<C, M, F>,
    M extends IMethodMetadata<C, M, F>,
    F extends IFieldMetadata<C, M, F>> extends Serializable {

    /**
     * @return JMethod object
     */
    JMethod getJMethod();

    /**
     * Sets the JMethod object (for changing some data).
     * @param jMethod the given JMethod object
     */
    void setJMethod(final JMethod jMethod);

    /**
     * @return parent metadata (class)
     */
    C getClassMetadata();

    /**
     * @param classMetadata parent metadata (class)
     */
    void setClassMetadata(final C classMetadata);

}
