/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.metadata;

import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * This class represents the annotation metadata of a method.
 * @author Florent Benoit
 * @param <C> type of class metadata
 * @param <M> type of method metadata
 * @param <F> type of field metadata
 */
public abstract class MethodMetadata<
    C extends IClassMetadata<C, M, F>,
    M extends IMethodMetadata<C, M, F>,
    F extends IFieldMetadata<C, M, F>>
        extends CommonMetadata implements IMethodMetadata<C, M, F> {

    /**
     * Logger.
     */
    //private static Log logger = LogFactory.getLog(MethodAnnotationMetadata.class);

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 1006697917121678878L;

    /**
     * Method on which we got metadata.
     */
    private JMethod jMethod = null;

    /**
     * Parent metadata.
     */
    private C classMetadata = null;

    /**
     * Constructor.
     * @param jMethod the method on which we will set/add metadata
     * @param classMetadata the parent metadata.
     */
    public MethodMetadata(final JMethod jMethod, final C classMetadata) {
        this.jMethod = jMethod;
        this.classMetadata = classMetadata;
    }

    /**
     * @return JMethod object
     */
    public final JMethod getJMethod() {
        return this.jMethod;
    }

    /**
     * Sets the JMethod object (for changing some data).
     * @param jMethod the given JMethod object
     */
    public final void setJMethod(final JMethod jMethod) {
        this.jMethod = jMethod;
    }

    /**
     * @return parent metadata (class)
     */
    public final C getClassMetadata() {
        return classMetadata;
    }

    /**
     * @param classMetadata parent metadata (class)
     */
    public final void setClassMetadata(final C classMetadata) {
        this.classMetadata = classMetadata;
    }

}
