/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.metadata.structures;

import java.io.Serializable;

/**
 * Annotation on class, method or field.
 * @author Gael Lalire
 */
public final class JAnnotation implements Serializable {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -6370092510864544109L;

    /**
     * annotation name.
     */
    private String className;

    /**
     * visibility of annotation.
     */
    private boolean visible;

    /**
     * Constructor.
     * @param className the class name of annotation
     * @param visible visible
     */
    public JAnnotation(final String className, final boolean visible) {
        if (className == null) {
            throw new IllegalArgumentException("Class name argument of JAnnotation constructor can not be null");
        }
        this.className = className;
        this.visible = visible;
    }

    /**
     * @return visibility of annotation
     */
    public boolean isVisible() {
        return visible;
    }

    /**
     * @return name of annotation class
     */
    public String getClassName() {
        return className;
    }

    /**
     * @return name hashcode
     */
    @Override
    public int hashCode() {
        return className.hashCode();
    }

    /**
     * @param obj the object to compare
     * @return true if same annotation.
     */
    @Override
    public boolean equals(final Object obj) {
        if (obj == this) {
            return true;
        }
        if (!(obj instanceof JAnnotation)) {
            return false;
        } else {
            JAnnotation jAnnotation = (JAnnotation) obj;
            if (className.equals(jAnnotation.className) && visible == jAnnotation.visible) {
                return true;
            }
            return false;
        }
    }

}
