/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.impl;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.util.List;
import java.util.Set;

import org.ow2.util.asm.ClassReader;
import org.ow2.util.scan.api.IScanner;
import org.ow2.util.scan.api.ScanException;
import org.ow2.util.scan.api.configurator.IArchiveConfigurator;

/**
 * ArchiveScanner.
 * This scanner use ASM to analyze classes.
 * @author Gael Lalire
 */
public final class ASMScannerImpl implements IScanner {

    /**
     * scan the class contained in url.
     * @param url url of the class
     * @param referencedClasses this set is filled during analyze
     * @param archiveConfiguratorList configurators to call
     * @throws ScanException if error occurs
     */
    public void scanClass(final URL url, final Set<String> referencedClasses,
            final List<? extends IArchiveConfigurator> archiveConfiguratorList) throws ScanException {
        InputStream is = null;
        try {
            URLConnection urlConnection = url.openConnection();
            urlConnection.setDefaultUseCaches(false);
            is = urlConnection.getInputStream();
            new ClassReader(is).accept(new ScanClassVisitor(archiveConfiguratorList, referencedClasses), 0);
        } catch (Exception ioe) {
            throw new ScanException("Error while analyzing file entry '" + url + "'", ioe);
        } finally {
            if (is != null) {
                try {
                    is.close();
                } catch (IOException e) {
                    throw new ScanException("Error while closing input stream of the entry '" + url
                            + "'", e);
                }
            }
        }

    }

}
