/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.impl;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.asm.AnnotationVisitor;
import org.ow2.util.asm.Type;
import org.ow2.util.scan.api.IAnnotationVisitor;

/**
 * ScanAnnotationVisitor.
 * @author Gael Lalire
 */
public final class ScanAnnotationVisitor implements AnnotationVisitor {

    /**
     * visitors.
     */
    private List<IAnnotationVisitor> annotationVisitors;

    /**
     * Constructor.
     * @param annotationVisitors visitors
     */
    public ScanAnnotationVisitor(final List<IAnnotationVisitor> annotationVisitors) {
        this.annotationVisitors = annotationVisitors;
    }

    /**
     * visit.
     * @param arg0 ?
     * @param arg1 ?
     */
    public void visit(final String arg0, final Object arg1) {
        Object value = arg1;
        if (value instanceof Type) {
            value = new TypeImpl((Type) value);
        }
        for (IAnnotationVisitor annotationVisitor : annotationVisitors) {
            if (annotationVisitor != null) {
                annotationVisitor.visit(arg0, value);
            }
        }
    }

    /**
     * visitAnnotation.
     * @param arg0 ?
     * @param arg1 ?
     * @return a scanner for all visitors
     */
    public AnnotationVisitor visitAnnotation(final String arg0, final String arg1) {
        List<IAnnotationVisitor> result = new ArrayList<IAnnotationVisitor>();
        for (IAnnotationVisitor annotationVisitor : annotationVisitors) {
            if (annotationVisitor != null) {
                result.add(annotationVisitor.visitAnnotation(arg0, arg1));
            }
        }
        return new ScanAnnotationVisitor(result);
    }

    /**
     * visitArray.
     * @param arg0 ?
     * @return a scanner for all visitors
     */
    public AnnotationVisitor visitArray(final String arg0) {
        List<IAnnotationVisitor> result = new ArrayList<IAnnotationVisitor>();
        for (IAnnotationVisitor annotationVisitor : annotationVisitors) {
            if (annotationVisitor != null) {
                result.add(annotationVisitor.visitArray(arg0));
            }
        }
        return new ScanAnnotationVisitor(result);
    }

    /**
     * visitEnd.
     */
    public void visitEnd() {
        for (IAnnotationVisitor annotationVisitor : annotationVisitors) {
            if (annotationVisitor != null) {
                annotationVisitor.visitEnd();
            }
        }
    }

    /**
     * visitEnum.
     * @param arg0 ?
     * @param arg1 ?
     * @param arg2 ?
     */
    public void visitEnum(final String arg0, final String arg1, final String arg2) {
        for (IAnnotationVisitor annotationVisitor : annotationVisitors) {
            if (annotationVisitor != null) {
                annotationVisitor.visitEnum(arg0, arg1, arg2);
            }
        }
    }

}
