/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.impl;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.asm.AnnotationVisitor;
import org.ow2.util.asm.commons.EmptyVisitor;
import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.configurator.ICommonConfigurator;
import org.ow2.util.scan.api.metadata.structures.JAnnotation;

/**
 * super class of all scanner.
 * @author Gael Lalire
 * @param <T> the class of configurator
 */
public class ScanCommonVisitor<T extends ICommonConfigurator> extends EmptyVisitor {

    /**
     * configurators.
     */
    private List<T> configurators;

    /**
     * @return configurators
     */
    protected List<T> getConfigurators() {
        return configurators;
    }

    /**
     * Set configurators.
     * @param configurators configurators
     */
    protected void setConfigurators(final List<T> configurators) {
        this.configurators = configurators;
    }

    /**
     * @param name annotation name
     * @param visible annotation visibility
     * @return a visitor
     */
    @Override
    public AnnotationVisitor visitAnnotation(final String name, final boolean visible) {
        JAnnotation jAnnotation = new JAnnotation(name, visible);
        List<IAnnotationVisitor> result = new ArrayList<IAnnotationVisitor>();

        for (T configurator : configurators) {
            IAnnotationVisitor annotationVisitor = configurator.getAnnotationVisitor(jAnnotation);
            result.add(annotationVisitor);
        }
        return new ScanAnnotationVisitor(result);
    }

}
