/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.impl;

import java.util.List;
import java.util.Set;

import org.ow2.util.asm.FieldVisitor;
import org.ow2.util.scan.api.configurator.IFieldConfigurator;

/**
 * ScanFieldVisitor.
 * @author Gael Lalire
 */
public final class ScanFieldVisitor extends ScanCommonVisitor<IFieldConfigurator> implements FieldVisitor {

    /**
     * A set to complete with referenced classes name.
     */
    private Set<String> referencedClasses;

    /**
     * Construtor.
     * @param fieldConfigurators configurators
     * @param referencedClasses a set to complete with referenced classes name.
     */
    public ScanFieldVisitor(final List<IFieldConfigurator> fieldConfigurators, final Set<String> referencedClasses) {
        setConfigurators(fieldConfigurators);
        this.referencedClasses = referencedClasses;
    }

    /**
     * call configurationComplete on each configurator.
     */
    @Override
    public void visitEnd() {
        for (IFieldConfigurator fieldConfigurator : getConfigurators()) {
            fieldConfigurator.configurationComplete(referencedClasses);
        }
    }

}
